from cx_Freeze import setup, Executable
class Setup():
  def __init__(self, FileName, Packages, nameOfExec, versionOfExec, descriptive):
    base = None    

    executables = [Executable(FileName, base=base)]

    packages = Packages
    options = {
        'build_exe': {    
            'packages':packages,
        },    
    }

    setup(
        name = nameOfExec,
        options = options,
        version = versionOfExec,
        description = descriptive,
        executables = executables
    )



import subprocess
import os
print("Starting...")
print("Converting...")
(stat, output) = subprocess.getstatusoutput("python ExampleScript.py build")
path = os.path.realpath(__file__).split("\\")
path[len(path)-1] = "build"
print("Done...At "+ "\\".join(path))




from setuptools import setup, find_packages
__project__ = "pytoexe"
__version__ = "1.0.7"
__description__ = "A Python module to convert python scripts to exe"
__packages__ = ["pytoexe"]
__requires__ = ["cx_Freeze"]
setup(
    name = __project__,
    version = __version__,
    author = "pennacap",
    maintainer = "pennacap",
    long_description = __description__,
    description = __description__,
    packages=find_packages(),
    requires = ["cx_Freeze"],
    python_requires='>=3.5.2',
)
